@@ -1,3 +1,5 @@
+import datetime
+
 from django.core.management.base import BaseCommand
 
 
@@ -26,6 +28,24 @@ class Command(BaseCommand):
             choices=["pg", "mongo"],
             default="mongo",
         )
+        parser.add_argument(
+            "-f",
+            "--from",
+            type=str,
+            help="From date format DD/MM/YYYY",
+        )
+        parser.add_argument(
+            "-t",
+            "--to",
+            type=str,
+            help="From date format DD/MM/YY",
+        )
+        parser.add_argument(
+            "-df",
+            "--date_field",
+            type=str,
+            help="Use this field to filter objects based on to/from"
+        )
         parser.add_argument(
             "-e",
             "--execute",
@@ -33,6 +53,13 @@ class Command(BaseCommand):
             help="Do not actually delete the object",
             default=False,
         )
+        parser.add_argument(
+            "-a",
+            "--atlas",
+            action="store_true",
+            help="Use atlas for the query",
+            default=False
+        )
 
     def handle(self, *args, **options):
         # we should import it here so that projects that don't use boto3 can still use this library
@@ -52,9 +79,36 @@ class Command(BaseCommand):
             raise NotImplementedError("Postgres has not been implement now")
         else:
             field = options["unique_field"]
-            groups = model_class.objects.aggregate(
+            if options["atlas"]:
+                if hasattr(model_class,"atlas"):
+                    qs = getattr(model_class, "atlas")
+                else:
+                    raise ValueError(f"Class {pmp} does not have an atlas object")
+            else:
+                qs = getattr(model_class, "objects")
+
+            date_field = options.get("date_field",order_by_field )
+
+            _from = options.get("from", None)
+            _from = datetime.datetime.strptime(_from, "%d/%m/%Y")
+            if _from:
+                qs = qs.filter(
+                    **{f"{date_field}__gte":
+                _from}
+                )
+            _to = options.get("to", None)
+            _to = datetime.datetime.strptime(_to, "%d/%m/%Y")
+            if _to:
+                qs = qs.filter(
+                    **{f"{date_field}__lte":
+                           _to}
+                )
+            if _from or _to:
+                print(f"Using {date_field} to filter research")
+
+            groups = qs.aggregate(
                 [
-                    {"$project": {f"{field}": 1, "_id": 1}},
+                    {"$project": {field: 1, "_id": 1, order_by_field: 1}},
                     {
                         "$group": {
                             "_id": f"${field}",
@@ -70,13 +124,14 @@ class Command(BaseCommand):
             for group in groups:
                 _id = group["_id"]
                 to_delete = model_class.objects.filter(id__in=group["ids"]).order_by(
-                    order_by_field
+                    f"-{order_by_field}"
                 )[1:]
                 if dry_run:
                     to_delete = to_delete.values_list("pk")
                     self.stdout.write(
                         self.style.SUCCESS(
-                            f"You would have deleted {len(to_delete)} objects {to_delete} with field {field} having value {_id}"
+                            f"You would have deleted {len(to_delete)} objects {to_delete} with field {field} having "
+                            f"value {_id}"
                         )
                     )
                 else:
